/*
 * Autogenerated by the Meson build system.
 * Do not edit, your changes will be lost.
 */

#pragma once

#define CAIRO_FEATURES_H

#define CAIRO_HAS_FC_FONT 1

#define CAIRO_HAS_FT_FONT 1

#define CAIRO_HAS_GOBJECT_FUNCTIONS 1

#define CAIRO_HAS_IMAGE_SURFACE 1

#define CAIRO_HAS_MIME_SURFACE 1

#define CAIRO_HAS_OBSERVER_SURFACE 1

#define CAIRO_HAS_PDF_SURFACE 1

#define CAIRO_HAS_PNG_FUNCTIONS 1

#define CAIRO_HAS_PS_SURFACE 1

#define CAIRO_HAS_RECORDING_SURFACE 1

#define CAIRO_HAS_SCRIPT_SURFACE 1

#define CAIRO_HAS_SVG_SURFACE 1

#define CAIRO_HAS_TEE_SURFACE 1

#define CAIRO_HAS_USER_FONT 1

#define CAIRO_HAS_XCB_SHM_FUNCTIONS 1

#define CAIRO_HAS_XCB_SURFACE 1

#define CAIRO_HAS_XLIB_SURFACE 1

#define CAIRO_HAS_XLIB_XRENDER_SURFACE 1

